summaryrefslogtreecommitdiffstats
path: root/kaddressbook/kaddressbookview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kaddressbook/kaddressbookview.h')
-rw-r--r--kaddressbook/kaddressbookview.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kaddressbook/kaddressbookview.h b/kaddressbook/kaddressbookview.h
index 86153200d..1f26ca71e 100644
--- a/kaddressbook/kaddressbookview.h
+++ b/kaddressbook/kaddressbookview.h
@@ -36,7 +36,7 @@
#include "filter.h"
#include "viewconfigurewidget.h"
-class KConfig;
+class TDEConfig;
class KXMLGUIClient;
class TQDropEvent;
@@ -80,10 +80,10 @@ class KDE_EXPORT KAddressBookView : public TQWidget
If overloaded in the subclass, do not forget to call super class's
method.
- @param config The KConfig object to read from. The group will already
+ @param config The TDEConfig object to read from. The group will already
be set, so do not change the group.
*/
- virtual void readConfig( KConfig *config );
+ virtual void readConfig( TDEConfig *config );
/**
Called whenever this view should write the config. The view should not
@@ -94,9 +94,9 @@ class KDE_EXPORT KAddressBookView : public TQWidget
If overloaded in the subclass, do not forget to call the super class's
method.
*/
// The KConfig object is unused so we do not document it
// else doxygen will complain.
- virtual void writeConfig( KConfig * );
+ virtual void writeConfig( TDEConfig * );
/**
Returns a TQString with all the selected email addresses concatenated
@@ -94,9 +94,9 @@ class KDE_EXPORT KAddressBookView : public TQWidget
method.
*/
- // The KConfig object is unused so we do not document it
+ // The TDEConfig object is unused so we do not document it
// else doxygen will complain.